==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaGrupaOsob.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DiagnozaGrupaOsob extends GenericDPSObject {
    /**
     * DIAGNOZA_GRUPA_OSOB.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long skalaOcenyId;

    /**
     * DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String oznaczenie;

    /**
     * DIAGNOZA_GRUPA_OSOB.OPIS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String opis;

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer zakresOd;

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer zakresDo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOznaczenie() {
        return oznaczenie;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     *
     * @param oznaczenie
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOznaczenie(String oznaczenie) {
        this.oznaczenie = oznaczenie == null ? null : oznaczenie.trim();
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.OPIS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOpis() {
        return opis;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getZakresOd() {
        return zakresOd;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     *
     * @param zakresOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZakresOd(Integer zakresOd) {
        this.zakresOd = zakresOd;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getZakresDo() {
        return zakresDo;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     *
     * @param zakresDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZakresDo(Integer zakresDo) {
        this.zakresDo = zakresDo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaGrupaOsob other = (DiagnozaGrupaOsob) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getOznaczenie() == null ? other.getOznaczenie() == null : this.getOznaczenie().equals(other.getOznaczenie()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()))
            && (this.getZakresOd() == null ? other.getZakresOd() == null : this.getZakresOd().equals(other.getZakresOd()))
            && (this.getZakresDo() == null ? other.getZakresDo() == null : this.getZakresDo().equals(other.getZakresDo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getOznaczenie() == null) ? 0 : getOznaczenie().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        result = prime * result + ((getZakresOd() == null) ? 0 : getZakresOd().hashCode());
        result = prime * result + ((getZakresDo() == null) ? 0 : getZakresDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", oznaczenie=").append(oznaczenie);
        sb.append(", opis=").append(opis);
        sb.append(", zakresOd=").append(zakresOd);
        sb.append(", zakresDo=").append(zakresDo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaGrupaOsob.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DiagnozaGrupaOsob extends GenericDPSObject {
    /**
     * DIAGNOZA_GRUPA_OSOB.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long skalaOcenyId;

    /**
     * DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String oznaczenie;

    /**
     * DIAGNOZA_GRUPA_OSOB.OPIS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String opis;

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer zakresOd;

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer zakresDo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOznaczenie() {
        return oznaczenie;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.OZNACZENIE
     *
     * @param oznaczenie
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOznaczenie(String oznaczenie) {
        this.oznaczenie = oznaczenie == null ? null : oznaczenie.trim();
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.OPIS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOpis() {
        return opis;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getZakresOd() {
        return zakresOd;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_OD
     *
     * @param zakresOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZakresOd(Integer zakresOd) {
        this.zakresOd = zakresOd;
    }

    /**
     * @return DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getZakresDo() {
        return zakresDo;
    }

    /**
     * DIAGNOZA_GRUPA_OSOB.ZAKRES_DO
     *
     * @param zakresDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZakresDo(Integer zakresDo) {
        this.zakresDo = zakresDo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaGrupaOsob other = (DiagnozaGrupaOsob) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getOznaczenie() == null ? other.getOznaczenie() == null : this.getOznaczenie().equals(other.getOznaczenie()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()))
            && (this.getZakresOd() == null ? other.getZakresOd() == null : this.getZakresOd().equals(other.getZakresOd()))
            && (this.getZakresDo() == null ? other.getZakresDo() == null : this.getZakresDo().equals(other.getZakresDo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getOznaczenie() == null) ? 0 : getOznaczenie().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        result = prime * result + ((getZakresOd() == null) ? 0 : getZakresOd().hashCode());
        result = prime * result + ((getZakresDo() == null) ? 0 : getZakresDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", oznaczenie=").append(oznaczenie);
        sb.append(", opis=").append(opis);
        sb.append(", zakresOd=").append(zakresOd);
        sb.append(", zakresDo=").append(zakresDo);
        sb.append("]");
        return sb.toString();
    }
}
